import type { DisplayObject } from '../display-objects';
import type { BaseStyleProps } from '../types';
import { CSSStyleValue } from './cssom';
import type { PropertyMetadata } from './interfaces';
import { StyleValueRegistry } from './interfaces';
export declare type CSSGlobalKeywords = 'unset' | 'initial' | 'inherit' | '';
export interface PropertyParseOptions {
    skipUpdateAttribute: boolean;
    skipParse: boolean;
}
/**
 * Blink used them in code generation(css_properties.json5)
 */
export declare const BUILT_IN_PROPERTIES: PropertyMetadata[];
export declare class DefaultStyleValueRegistry implements StyleValueRegistry {
    /**
     * need recalc later
     */
    dirty: boolean;
    private cache;
    private unresolvedProperties;
    private propertySyntaxFactory;
    private sceneGraphService;
    /**
     * eg.
     *
     * document: {
     *   fontSize: [
     *
     *   ]
     * }
     */
    private cascadeProperties;
    init(): void;
    registerMetadata(metadata: PropertyMetadata): void;
    unregisterMetadata(name: string): void;
    getMetadata(name: string): PropertyMetadata;
    getPropertySyntax(syntax: string): import("./CSSProperty").CSSProperty<any, any>;
    /**
     * * parse value, eg.
     * fill: 'red' => CSSRGB
     * translateX: '10px' => CSSUnitValue { unit: 'px', value: 10 }
     * fontSize: '2em' => { unit: 'px', value: 32 }
     *
     * * calculate used value
     * * post process
     */
    processProperties(object: DisplayObject, attributes: BaseStyleProps, options?: Partial<PropertyParseOptions>): void;
    /**
     * string -> parsed value
     */
    parseProperty(name: string, value: any, object: DisplayObject): CSSStyleValue;
    /**
     * computed value -> used value
     */
    computeProperty(name: string, computed: CSSStyleValue, object: DisplayObject): boolean;
    postProcessProperty(name: string, object: DisplayObject): void;
    isPropertyResolved(object: DisplayObject, name: string): boolean;
    /**
     * resolve later
     */
    addUnresolveProperty(object: DisplayObject, name: string): void;
    tryToResolveProperty(object: DisplayObject, name: string, options?: {
        inherited?: boolean;
    }): any;
    recalc(object: DisplayObject): void;
    /**
     * update geometry when relative props changed,
     * eg. r of Circle, width/height of Rect
     */
    updateGeometry(object: DisplayObject): void;
    private isPropertyInheritable;
}
//# sourceMappingURL=StyleValueRegistry.d.ts.map