import type { AbsoluteArray, CurveArray, PathArray } from '@antv/util';
import type { DisplayObjectConfig } from '../dom';
import { Point } from '../shapes';
import type { Rectangle } from '../shapes/Rectangle';
import type { BaseStyleProps, ParsedBaseStyleProps } from '../types';
import { DisplayObject } from './DisplayObject';
export interface PathStyleProps extends BaseStyleProps {
    path?: string | PathArray;
    d?: string | PathArray;
}
export interface PathSegment {
    command: PathArray[0];
    currentPoint: [number, number];
    prePoint: [number, number] | null;
    nextPoint: [number, number] | null;
    startTangent: [number, number] | null;
    endTangent: [number, number] | null;
    params: PathArray[0];
}
export interface ParsedPathStyleProps extends ParsedBaseStyleProps {
    path: {
        absolutePath: AbsoluteArray;
        hasArc: boolean;
        segments: PathSegment[];
        polygons: [number, number][][];
        polylines: [number, number][][];
        curve: CurveArray;
        totalLength: number;
        zCommandIndexes: number[];
        rect: Rectangle;
    };
}
export declare class Path extends DisplayObject<PathStyleProps, ParsedPathStyleProps> {
    constructor({ style, ...rest }?: DisplayObjectConfig<PathStyleProps>);
    getTotalLength(): number;
    /**
     * Get point according to ratio
     */
    getPoint(ratio: number): Point;
    /**
     * Get start tangent vector
     */
    getStartTangent(): number[][];
    /**
     * Get end tangent vector
     */
    getEndTangent(): number[][];
}
//# sourceMappingURL=Path.d.ts.map