import type { CSSGlobalKeywords, CSSKeywordValue, CSSUnitValue } from '../css';
import type { DisplayObjectConfig } from '../dom/interfaces';
import type { TextMetrics } from '../services';
import type { BaseStyleProps, ParsedBaseStyleProps } from '../types';
import { DisplayObject } from './DisplayObject';
export interface TextStyleProps extends BaseStyleProps {
    x?: number | string;
    y?: number | string;
    text: string;
    /** 设置文本内容的当前对齐方式 */
    textAlign?: CSSGlobalKeywords | 'start' | 'center' | 'end' | 'left' | 'right';
    /** 设置在绘制文本时使用的当前文本基线 */
    textBaseline?: CSSGlobalKeywords | 'top' | 'hanging' | 'middle' | 'alphabetic' | 'ideographic' | 'bottom';
    /** 字体样式 */
    fontStyle?: CSSGlobalKeywords | 'normal' | 'italic' | 'oblique';
    /** 文本字体大小 */
    fontSize?: number | string;
    /** 文本字体 */
    fontFamily?: string;
    /** 文本粗细 */
    fontWeight?: CSSGlobalKeywords | 'normal' | 'bold' | 'bolder' | 'lighter' | number;
    /** 字体变体 */
    fontVariant?: CSSGlobalKeywords | 'normal' | 'small-caps' | string;
    /** 文本行高 */
    lineHeight?: number | string;
    letterSpacing?: number | string;
    whiteSpace?: 'pre';
    leading?: number;
    wordWrap?: boolean;
    wordWrapWidth?: number;
    dx?: number | string;
    dy?: number | string;
}
export interface ParsedTextStyleProps extends ParsedBaseStyleProps {
    x: CSSUnitValue;
    y: CSSUnitValue;
    text: string;
    /** 设置文本内容的当前对齐方式 */
    textAlign?: CSSKeywordValue;
    /** 设置在绘制文本时使用的当前文本基线 */
    textBaseline?: CSSKeywordValue;
    /** 字体样式 */
    fontStyle?: CSSKeywordValue;
    /** 文本字体大小 */
    fontSize?: CSSUnitValue;
    /** 文本字体 */
    fontFamily?: string;
    /** 文本粗细 */
    fontWeight?: CSSKeywordValue;
    /** 字体变体 */
    fontVariant?: CSSKeywordValue;
    /** 文本行高 */
    lineHeight?: CSSUnitValue;
    letterSpacing?: CSSUnitValue;
    whiteSpace?: 'pre';
    leading?: number;
    wordWrap?: boolean;
    wordWrapWidth?: number;
    metrics?: TextMetrics;
    dx?: CSSUnitValue;
    dy?: CSSUnitValue;
}
/**
 * <text> @see https://developer.mozilla.org/en-US/docs/Web/API/SVGTextElement
 */
export declare class Text extends DisplayObject<TextStyleProps, ParsedTextStyleProps> {
    /**
     * @see https://developer.mozilla.org/en-US/docs/Web/API/SVGTextContentElement#constants
     */
    constructor({ style, ...rest }?: DisplayObjectConfig<TextStyleProps>);
    /**
     * @see https://developer.mozilla.org/en-US/docs/Web/API/SVGTextContentElement
     */
    getComputedTextLength(): number;
    getLineBoundingRects(): import("..").Rectangle[];
}
//# sourceMappingURL=Text.d.ts.map